#
# spec file for package python-requests-hawk
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-requests-hawk
Version:        1.2.1
Release:        2.3
Summary:        Hawk authentication strategy for the requests python library
License:        Apache-2.0
URL:            https://github.com/mozilla-services/requests-hawk
Source:         https://files.pythonhosted.org/packages/source/r/requests-hawk/requests-hawk-%{version}.tar.gz
BuildRequires:  %{python_module mohawk}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-mohawk
Requires:       python-requests
BuildArch:      noarch
%python_subpackages

%description
This project allows you to use the python requests library with the hawk
authentification mechanism.

Hawk itself does not provide any mechanism for obtaining or transmitting the
set of shared credentials required, but this project proposes a scheme we use
across mozilla services projects.

%prep
%setup -q -n requests-hawk-%{version}
sed -ie 's/\(assertEqual\)s/\1/' requests_hawk/tests/test_hawkauth.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pyunittest discover -v

%files %{python_files}
%license LICENSE.txt
%doc CHANGES.txt README.rst
%{python_sitelib}/requests_hawk
%{python_sitelib}/requests_hawk-%{version}.dist-info

%changelog
* Tue Mar 12 2024 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyproject macros.
- Correct one test unit assertion method.
* Mon May  8 2023 Antoine Belvire <antoine.belvire@opensuse.org>
- Update to version 1.2.1: Add support for ext external data string
  (gh#mozilla-services/requests-hawk#34)
- Fix rpmlint warnings.
* Sat Jun  5 2021 Antoine Belvire <antoine.belvire@opensuse.org>
- Update to version 1.1.1:
  * Handle cases where Content-Type is defined as bytes rather than
  string. (#25)
  * Allow for app mohawk sender parameter configuration.
* Thu Jun  3 2021 pgajdos@suse.com
- %%check: use %%pyunittest rpm macro
* Sat Jan  2 2021 Antoine Belvire <antoine.belvire@opensuse.org>
- Update to version 1.1.0:
  * Allow to skip hashing request and response bodies with
    `always_hash_content`.
* Wed Mar 18 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.0.1:
  - Add Python 3 support. (#22)
- Enable tests
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sat Dec  2 2017 antoine.belvire@opensuse.org
- Initial package: python-requests-hawk 1.0.0.
